# AdviserResultResponseResult

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**error** | **bool** | A flag indicating error during the advise |
**error_msg** | **str** | An error message describing the error encountered |
**parameters** | **object** | Parameters supplied on advise together with user inputs |
**report** | [**AdviserResultResponseResultReport**](AdviserResultResponseResultReport.md) |  |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

